==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/kinetics/simpleRelays/encased/EncasedShaftBlock.java <==
package com.zurrtum.create.content.kinetics.simpleRelays.encased;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.api.schematic.requirement.SpecialBlockItemRequirement;
import com.zurrtum.create.content.decoration.encasing.EncasedBlock;
import com.zurrtum.create.content.kinetics.base.AbstractEncasedShaftBlock;
import com.zurrtum.create.content.kinetics.base.KineticBlockEntity;
import com.zurrtum.create.content.kinetics.base.RotatedPillarKineticBlock;
import com.zurrtum.create.content.schematics.requirement.ItemRequirement;
import com.zurrtum.create.foundation.block.IBE;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_6088;

public class EncasedShaftBlock extends AbstractEncasedShaftBlock implements IBE<KineticBlockEntity>, SpecialBlockItemRequirement, EncasedBlock {

    private final class_2248 casing;

    public EncasedShaftBlock(class_2251 properties, class_2248 casing) {
        super(properties);
        this.casing = casing;
    }

    public static EncasedShaftBlock andesite(class_2251 properties) {
        return new EncasedShaftBlock(properties, AllBlocks.ANDESITE_CASING);
    }

    public static EncasedShaftBlock brass(class_2251 properties) {
        return new EncasedShaftBlock(properties, AllBlocks.BRASS_CASING);
    }

    @Override
    public class_1269 onSneakWrenched(class_2680 state, class_1838 context) {
        if (context.method_8045().field_9236)
            return class_1269.field_5812;
        context.method_8045().method_20290(class_6088.field_31144, context.method_8037(), class_2248.method_9507(state));
        KineticBlockEntity.switchToBlockState(
            context.method_8045(),
            context.method_8037(),
            AllBlocks.SHAFT.method_9564().method_11657(AXIS, state.method_11654(AXIS))
        );
        return class_1269.field_5812;
    }

    @Override
    public class_1799 method_9574(class_4538 world, class_2338 pos, class_2680 state, boolean includeData) {
        return casing.method_8389().method_7854();
    }

    @Override
    public ItemRequirement getRequiredItems(class_2680 state, class_2586 be) {
        return ItemRequirement.of(AllBlocks.SHAFT.method_9564(), be);
    }

    @Override
    public Class<KineticBlockEntity> getBlockEntityClass() {
        return KineticBlockEntity.class;
    }

    @Override
    public class_2591<? extends KineticBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.ENCASED_SHAFT;
    }

    @Override
    public class_2248 getCasing() {
        return casing;
    }

    @Override
    public void handleEncasing(class_2680 state, class_1937 level, class_2338 pos, class_1799 heldItem, class_1657 player, class_1268 hand, class_3965 ray) {
        KineticBlockEntity.switchToBlockState(
            level,
            pos,
            method_9564().method_11657(RotatedPillarKineticBlock.AXIS, state.method_11654(RotatedPillarKineticBlock.AXIS))
        );
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/content/kinetics/simpleRelays/encased/EncasedShaftBlock.java <==
package com.zurrtum.create.content.kinetics.simpleRelays.encased;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllBlocks;
import com.zurrtum.create.api.schematic.requirement.SpecialBlockItemRequirement;
import com.zurrtum.create.content.decoration.encasing.EncasedBlock;
import com.zurrtum.create.content.kinetics.base.AbstractEncasedShaftBlock;
import com.zurrtum.create.content.kinetics.base.KineticBlockEntity;
import com.zurrtum.create.content.kinetics.base.RotatedPillarKineticBlock;
import com.zurrtum.create.content.schematics.requirement.ItemRequirement;
import com.zurrtum.create.foundation.block.IBE;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1838;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2586;
import net.minecraft.class_2591;
import net.minecraft.class_2680;
import net.minecraft.class_3965;
import net.minecraft.class_4538;
import net.minecraft.class_6088;

public class EncasedShaftBlock extends AbstractEncasedShaftBlock implements IBE<KineticBlockEntity>, SpecialBlockItemRequirement, EncasedBlock {

    private final class_2248 casing;

    public EncasedShaftBlock(class_2251 properties, class_2248 casing) {
        super(properties);
        this.casing = casing;
    }

    public static EncasedShaftBlock andesite(class_2251 properties) {
        return new EncasedShaftBlock(properties, AllBlocks.ANDESITE_CASING);
    }

    public static EncasedShaftBlock brass(class_2251 properties) {
        return new EncasedShaftBlock(properties, AllBlocks.BRASS_CASING);
    }

    @Override
    public class_1269 onSneakWrenched(class_2680 state, class_1838 context) {
        if (context.method_8045().method_8608())
            return class_1269.field_5812;
        context.method_8045().method_20290(class_6088.field_31144, context.method_8037(), class_2248.method_9507(state));
        KineticBlockEntity.switchToBlockState(
            context.method_8045(),
            context.method_8037(),
            AllBlocks.SHAFT.method_9564().method_11657(AXIS, state.method_11654(AXIS))
        );
        return class_1269.field_5812;
    }

    @Override
    public class_1799 method_9574(class_4538 world, class_2338 pos, class_2680 state, boolean includeData) {
        return casing.method_8389().method_7854();
    }

    @Override
    public ItemRequirement getRequiredItems(class_2680 state, class_2586 be) {
        return ItemRequirement.of(AllBlocks.SHAFT.method_9564(), be);
    }

    @Override
    public Class<KineticBlockEntity> getBlockEntityClass() {
        return KineticBlockEntity.class;
    }

    @Override
    public class_2591<? extends KineticBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.ENCASED_SHAFT;
    }

    @Override
    public class_2248 getCasing() {
        return casing;
    }

    @Override
    public void handleEncasing(
        class_2680 state,
        class_1937 level,
        class_2338 pos,
        class_1799 heldItem,
        class_1657 player,
        class_1268 hand,
        class_3965 ray
    ) {
        KineticBlockEntity.switchToBlockState(
            level,
            pos,
            method_9564().method_11657(RotatedPillarKineticBlock.AXIS, state.method_11654(RotatedPillarKineticBlock.AXIS))
        );
    }
}
